import 'package:flutter/material.dart';
import 'package:flutter_custom_toolbox/flutter_toolbox.dart';

import 'package:random/common/cubit/nav/nav_cubit_pages.dart';

import 'package:random/cubit/activity/activity_cubit.dart';
import 'package:random/ui/parameters/parameter_painter_board_size.dart';
import 'package:random/ui/parameters/parameter_painter_colors_count.dart';

class ApplicationConfig {
  static const String parameterCodeBoardSize = 'boardSize';
  static const String parameterCodeColorsCount = 'colorsCount';

  static const String boardSizeValueSmall = '6';
  static const String boardSizeValueMedium = '10';
  static const String boardSizeValueLarge = '16';
  static const String boardSizeValueExtraLarge = '24';

  static const String colorsCountVeryLow = '4';
  static const String colorsCountLow = '5';
  static const String colorsCountMedium = '6';
  static const String colorsCountHigh = '7';

  static final ApplicationConfigDefinition config = ApplicationConfigDefinition(
    appTitle: 'Random application',
    activitySettings: [
      // board size
      ApplicationSettingsParameter(
        code: parameterCodeBoardSize,
        values: [
          ApplicationSettingsParameterItemValue(
            value: boardSizeValueSmall,
            color: Colors.green,
          ),
          ApplicationSettingsParameterItemValue(
            value: boardSizeValueMedium,
            color: Colors.orange,
            isDefault: true,
          ),
          ApplicationSettingsParameterItemValue(
            value: boardSizeValueLarge,
            color: Colors.red,
          ),
          ApplicationSettingsParameterItemValue(
            value: boardSizeValueExtraLarge,
            color: Colors.purple,
          ),
        ],
        customPainter: (context, value) => ParameterPainterBoardSize(
          context: context,
          value: value,
        ),
      ),

      // colors count
      ApplicationSettingsParameter(
        code: parameterCodeColorsCount,
        values: [
          ApplicationSettingsParameterItemValue(
            value: colorsCountVeryLow,
            color: Colors.green,
          ),
          ApplicationSettingsParameterItemValue(
            value: colorsCountLow,
            color: Colors.orange,
          ),
          ApplicationSettingsParameterItemValue(
            value: colorsCountMedium,
            color: Colors.red,
            isDefault: true,
          ),
          ApplicationSettingsParameterItemValue(
            value: colorsCountHigh,
            color: Colors.purple,
          ),
        ],
        customPainter: (context, value) => ParameterPainterColorsCount(
          context: context,
          value: value,
        ),
      ),
    ],
    startNewActivity: (BuildContext context) {
      BlocProvider.of<ActivityCubit>(context).startNewActivity(context);
      BlocProvider.of<NavCubitPage>(context).goToPageGame();
    },
    deleteCurrentActivity: (BuildContext context) {
      BlocProvider.of<ActivityCubit>(context).deleteSavedActivity();
    },
    resumeActivity: (BuildContext context) {
      BlocProvider.of<ActivityCubit>(context).resumeSavedActivity();
      BlocProvider.of<NavCubitPage>(context).goToPageGame();
    },
  );
}
